{-------------------------------------------------------------------------------
The contents of this file are subject to the Mozilla Public License
Version 1.1 (the "License"); you may not use this file except in compliance
with the License. You may obtain a copy of the License at
http://www.mozilla.org/MPL/

Software distributed under the License is distributed on an "AS IS" basis,
WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
the specific language governing rights and limitations under the License.

The Original Code is: uMain.pas, released 2001-08-28.

The Original Code is part of the HighlighterDemo project, written by Pieter Polak
for the SynEdit component suite.
All Rights Reserved.

Contributors to the SynEdit project are listed in the Contributors.txt file.

Alternatively, the contents of this file may be used under the terms of the
GNU General Public License Version 2 or later (the "GPL"), in which case
the provisions of the GPL are applicable instead of those above.
If you wish to allow use of your version of this file only under the terms
of the GPL and not to allow others to use your version of this file
under the MPL, indicate your decision by deleting the provisions above and
replace them with the notice and other provisions required by the GPL.
If you do not delete the provisions above, a recipient may use your version
of this file under either the MPL or the GPL.

$Id: uMain.pas,v 1.1 2001/08/28 09:33:51 plpolak Exp $

You may retrieve the latest version of this file at the SynEdit home page,
located at http://SynEdit.SourceForge.net

Known Issues:
-------------------------------------------------------------------------------}

unit uMain;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  SynEdit, SynCompletionProposal, Menus;

type
  TForm1 = class(TForm)
    SynEdit1: TSynEdit;
    SynCmpPrp: TSynCompletionProposal;
    MainMenu1: TMainMenu;
    File1: TMenuItem;
    Exit1: TMenuItem;
    N2: TMenuItem;
    SaveAs1: TMenuItem;
    Save1: TMenuItem;
    N3: TMenuItem;
    Open1: TMenuItem;
    New1: TMenuItem;
    Edit1: TMenuItem;
    Replace1: TMenuItem;
    Find1: TMenuItem;
    N5: TMenuItem;
    Paste1: TMenuItem;
    Copy1: TMenuItem;
    Cut1: TMenuItem;
    N6: TMenuItem;
    Redo: TMenuItem;
    Undo1: TMenuItem;
    OpenDialog1: TOpenDialog;
    SaveDialog1: TSaveDialog;
    FindDialog1: TFindDialog;
    ReplaceDialog1: TReplaceDialog;
    procedure FormCreate(Sender: TObject);
    procedure Exit1Click(Sender: TObject);
    procedure SaveAs1Click(Sender: TObject);
    procedure Save1Click(Sender: TObject);
    procedure Open1Click(Sender: TObject);
    procedure New1Click(Sender: TObject);
    procedure Undo1Click(Sender: TObject);
    procedure RedoClick(Sender: TObject);
    procedure Cut1Click(Sender: TObject);
    procedure Copy1Click(Sender: TObject);
    procedure Paste1Click(Sender: TObject);
    procedure Find1Click(Sender: TObject);
    procedure FindDialog1FindClick(Sender: TObject);
    procedure Replace1Click(Sender: TObject);
    procedure ReplaceDialog1ReplaceClick(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  Form1: TForm1;
  fileName: String;
implementation

{$R *.DFM}

uses
  //SynHighlighterSample;
  SynHighlighterJASS;

procedure TForm1.FormCreate(Sender: TObject);
var
  HL: TSynJASSSyn;

begin
  fileName := '';
  HL := TSynJASSSyn.Create(Self);
  HL.StringAttri.Foreground := clRed;
  HL.KeyAttri.Foreground := clBlue;
  HL.NumberAttri.Foreground := clTeal;
  HL.SymbolAttri.Style := [fsBold];
  HL.SymbolAttri.Foreground := clFuchsia;
  HL.CommentAttri.Foreground := clOlive;
  SynEdit1.Highlighter := HL;
  SynEdit1.ClearAll;
  SynEdit1.Text := HL.SampleSource;

  SynCmpPrp.CaseSensitive := true;
  SynCmpPrp.UsePrettyText := true;
  SynCmpPrp.UseInsertList := true;

  SynCmpPrp.InsertList.LoadFromFile('unitsInsertList.txt');
  SynCmpPrp.ItemList.LoadFromFile('unitsItemList.txt');
end;

procedure TForm1.Exit1Click(Sender: TObject);
begin
  Application.Terminate;  
end;

procedure TForm1.SaveAs1Click(Sender: TObject);
begin
  if SaveDialog1.Execute then
  begin
    fileName := SaveDialog1.FileName;
    SynEdit1.Lines.SaveToFile(SaveDialog1.FileName);
  end;
end;

procedure TForm1.Save1Click(Sender: TObject);
begin
  if fileName = '' then
    if SaveDialog1.Execute then
    begin
      fileName := SaveDialog1.FileName;
      SynEdit1.Lines.SaveToFile(SaveDialog1.FileName);
    end
  else
    SynEdit1.Lines.SaveToFile(fileName);
end;

procedure TForm1.Open1Click(Sender: TObject);
begin
if OpenDialog1.Execute then
  begin
    fileName := OpenDialog1.FileName;
    SynEdit1.Lines.LoadFromFile(OpenDialog1.FileName);
  end;
end;

procedure TForm1.New1Click(Sender: TObject);
begin
  fileName := '';
  SynEdit1.Text := '';
end;

procedure TForm1.Undo1Click(Sender: TObject);
begin
  SynEdit1.Undo;
end;

procedure TForm1.RedoClick(Sender: TObject);
begin
  SynEdit1.Redo;
end;

procedure TForm1.Cut1Click(Sender: TObject);
begin
  SynEdit1.CutToClipboard;
end;

procedure TForm1.Copy1Click(Sender: TObject);
begin
  SynEdit1.CopyToClipboard;
end;

procedure TForm1.Paste1Click(Sender: TObject);
begin
  SynEdit1.PasteFromClipboard;
end;

procedure TForm1.Find1Click(Sender: TObject);
begin
  FindDialog1.Execute;
end;

procedure TForm1.FindDialog1FindClick(Sender: TObject);
var
  Options: TSynSearchOptions;
begin
  Options := [];
  if not (frDown in FindDialog1.Options) then
    Include(Options, ssoBackwards);
  if frMatchCase in FindDialog1.Options then
    Include(Options, ssoMatchCase);
  //Include(Options, ssoEntireScope);
  if frWholeWord in FindDialog1.Options then
    Include(Options, ssoWholeWord);
  if SynEdit1.SearchReplace(FindDialog1.FindText, '', Options) = 0 then
  begin
    MessageBeep(MB_ICONASTERISK);
    if ssoBackwards in Options then
      SynEdit1.BlockEnd := SynEdit1.BlockBegin
    else
      SynEdit1.BlockBegin := SynEdit1.BlockEnd;
    SynEdit1.CaretXY := SynEdit1.BlockBegin;
  end;
end;

procedure TForm1.Replace1Click(Sender: TObject);
begin
  ReplaceDialog1.Execute;
end;

procedure TForm1.ReplaceDialog1ReplaceClick(Sender: TObject);
var
  Options: TSynSearchOptions;
begin
  Options := [ssoPrompt];
  if frReplace in ReplaceDialog1.Options then
  begin
    if SynEdit1.SelAvail and (SynEdit1.SelText = ReplaceDialog1.FindText) then
      SynEdit1.CaretX := SynEdit1.BlockBegin.x;
    Include(Options, ssoReplace);
  end;
  if frReplaceAll in ReplaceDialog1.Options then
  begin
    if SynEdit1.SelAvail and (SynEdit1.SelText = ReplaceDialog1.FindText) then
      SynEdit1.CaretX := SynEdit1.BlockBegin.x;
    Include(Options, ssoReplaceAll);
  end;
  if not (frDown in ReplaceDialog1.Options) then
    Include(Options, ssoBackwards);
  if frMatchCase in ReplaceDialog1.Options then
    Include(Options, ssoMatchCase);
  //Include(Options, ssoEntireScope);
  if frWholeWord in ReplaceDialog1.Options then
    Include(Options, ssoWholeWord);
  if SynEdit1.SearchReplace(ReplaceDialog1.FindText, ReplaceDialog1.ReplaceText, Options) = 0 then
  begin
    MessageBeep(MB_ICONASTERISK);
    if ssoBackwards in Options then
      SynEdit1.BlockEnd := SynEdit1.BlockBegin
    else
      SynEdit1.BlockBegin := SynEdit1.BlockEnd;
    SynEdit1.CaretXY := SynEdit1.BlockEnd;
  end;
end;

end.
